package com.ruoyi.asset.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.asset.domain.TbAsset;
import com.ruoyi.asset.domain.dto.TbAssetDTO;
import com.ruoyi.common.core.domain.AjaxResult;
import org.springframework.transaction.annotation.Transactional;

/**
 * 资产信息Service接口
 * 
 * @author 原动力
 * @date 2023-03-27
 */
@Transactional
public interface ITbAssetService extends IService<TbAsset>
{
    /**
     * 查询资产信息
     * 
     * @param id 资产信息主键
     * @return 资产信息
     */
    public TbAsset selectTbAssetById(Long id);

    /**
     * 查询资产信息列表
     * 
     * @param tbAsset 资产信息
     * @return 资产信息集合
     */
    public List<TbAsset> selectTbAssetList(TbAsset tbAsset);

    /**
     * 新增资产信息
     * 
     * @param tbAsset 资产信息
     * @return 结果
     */
    public int insertTbAsset(TbAsset tbAsset);

    /**
     * 修改资产信息
     * 
     * @param tbAsset 资产信息
     * @return 结果
     */
    public int updateTbAsset(TbAsset tbAsset);

    /**
     * 批量删除资产信息
     * 
     * @param ids 需要删除的资产信息主键集合
     * @return 结果
     */
    public int deleteTbAssetByIds(Long[] ids);

    /**
     * 删除资产信息信息
     *
     * @param id 资产信息主键
     * @return 结果
     */
    public int deleteTbAssetById(Long id);

    /**
     * 批量新增
     *
     * @param tbAssetList 资产信息集合
     * @return 结果
     */
    boolean batchTbAsset(List<TbAsset> tbAssetList);

    /**
     * 导出数据
     *
     * @return 资产信息集合
     */
    List<TbAsset> exportData(TbAsset tbAsset);

    /**
     * 查询资产信息
     *
     * @param barCode 资产条形码
     * @param numberOrName 资产编号或名称
     * @return 资产信息列表
     */
    List<TbAssetDTO> selectTbAsset(String barCode, String numberOrName);

    /**
     * 分页查询资产信息
     *
     * @param pageNum 页码
     * @param pageSize 数量
     * @param numberOrName 关键词
     * @return 资产信息列表
     */
    Page<TbAssetDTO> selectTbAssetPage(Integer pageNum, Integer pageSize, String numberOrName);

    /**
     * 资产信息统计
     *
     * @return 结果
     */
    AjaxResult countTbAsset();
}
