package com.ruoyi.asset.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.asset.domain.dto.TbAssetDTO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.asset.domain.TbAsset;
import com.ruoyi.asset.service.ITbAssetService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 资产信息Controller
 * 
 * @author 原动力
 * @date 2023-03-27
 */
@Api(tags = "资产信息")
@RestController
@RequestMapping("/asset/asset")
public class TbAssetController extends BaseController
{
    @Autowired
    private ITbAssetService tbAssetService;

    /**
     * 查询资产信息列表
     */
    @ApiOperation("查询资产信息列表")
    @PreAuthorize("@ss.hasPermi('asset:asset:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAsset tbAsset)
    {
        startPage();
        List<TbAsset> list = tbAssetService.selectTbAssetList(tbAsset);
        return getDataTable(list);
    }

    /**
     * 导出资产信息列表
     */
    @ApiOperation("导出资产信息列表")
    @PreAuthorize("@ss.hasPermi('asset:asset:export')")
    @Log(title = "资产信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAsset tbAsset)
    {
        List<TbAsset> list = tbAssetService.exportData(tbAsset);
        ExcelUtil<TbAsset> util = new ExcelUtil<TbAsset>(TbAsset.class);
        util.exportExcel(response, list, "资产信息数据");
    }

    /**
     * 导入
     */
    @ApiOperation("导入资产信息")
    @Log(title = "资产信息", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('asset:asset:add')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file) throws Exception {
        // 获取模板工具
        ExcelUtil<TbAsset> util = new ExcelUtil<>(TbAsset.class);
        List<TbAsset> tbAssets = util.importExcel(file.getInputStream());
        if (tbAssets.isEmpty()) {
            return error("数据不得为空");
        }
        boolean result = tbAssetService.batchTbAsset(tbAssets);
        return result ? success() : error();
    }

    @ApiOperation("资产信息模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TbAsset> util = new ExcelUtil<>(TbAsset.class);
        util.importTemplateExcel(response, "资产信息数据");
    }

    /**
     * 获取资产信息详细信息
     */
    @ApiOperation("获取资产信息详细信息")
    @PreAuthorize("@ss.hasPermi('asset:asset:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tbAssetService.selectTbAssetById(id));
    }

    /**
     * 新增资产信息
     */
    @ApiOperation("新增资产信息")
    @PreAuthorize("@ss.hasPermi('asset:asset:add')")
    @Log(title = "资产信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAsset tbAsset)
    {
        return toAjax(tbAssetService.insertTbAsset(tbAsset));
    }

    /**
     * 修改资产信息
     */
    @ApiOperation("修改资产信息")
    @PreAuthorize("@ss.hasPermi('asset:asset:edit')")
    @Log(title = "资产信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAsset tbAsset)
    {
        return toAjax(tbAssetService.updateTbAsset(tbAsset));
    }

    /**
     * 删除资产信息
     */
    @ApiOperation("删除资产信息")
    @PreAuthorize("@ss.hasPermi('asset:asset:remove')")
    @Log(title = "资产信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetService.deleteTbAssetByIds(ids));
    }

    /**
     * 小程序：获取资产信息
     */
    @ApiOperation("小程序：获取资产信息")
    @PreAuthorize("@ss.hasPermi('asset:asset:query')")
    @GetMapping(value = "/search")
    public AjaxResult  selectTbAssetByBarCode(
            @RequestParam(value = "barCode", required = false) String barCode,
            @RequestParam(value = "numberOrName", required = false) String numberOrName
    ) {
        List<TbAssetDTO> tbAssetDTOS = tbAssetService.selectTbAsset(barCode, numberOrName);
        if (barCode != null) {
            if (tbAssetDTOS.isEmpty()) {
                return AjaxResult.success("查询成功", new TbAsset());
            }
            return AjaxResult.success(tbAssetDTOS.get(0));
        }
        return AjaxResult.success(tbAssetDTOS);
    }

    /**
     * 小程序：获取资产信息
     */
    @ApiOperation("小程序：获取资产信息")
    @PreAuthorize("@ss.hasPermi('asset:asset:query')")
    @GetMapping(value = "/search/list/{pageNum}/{pageSize}")
    public AjaxResult  selectTbAssetByBarCode(
            @PathVariable("pageNum") Integer pageNum,
            @PathVariable("pageSize") Integer pageSize,
            @RequestParam(value = "numberOrName", required = false) String numberOrName
    ) {
        Page<TbAssetDTO> tbAssetDTOPage = tbAssetService.selectTbAssetPage(pageNum, pageSize, numberOrName);
        return AjaxResult.success(tbAssetDTOPage);
    }

    /**
     * 资产信息统计
     */
    @ApiOperation("资产信息统计")
    @PreAuthorize("@ss.hasPermi('asset:asset:query')")
    @GetMapping(value = "/count")
    public AjaxResult countTbAsset() {
        return tbAssetService.countTbAsset();
    }
}
